// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1

Column{
   id: col
   property string line1: "NOT SET"
   property string line2: "NOT SET"
   property string line3: "NOT SET"
   property string line4: "NOT SET"

   property string pulseVal: "---"
   property string kaVal: "---"

//   property color bckgColor: "#315995"

   property int flag1: 0;
   property bool msErr: false;
   property bool kaErr: false;

   spacing: 5

   signal enterClicked();
   onEnterClicked: {
      if (flag1 === 1) //check pulse value and set flag to 2 if ok
      {
         flag1 = 2;
      }
      else if (flag1 === 2)//check ka value and set flag to 2 if ok
      {
         flag1 = 1;
      }
   }

   signal digitClicked(int digit);
   onDigitClicked: {
      if (flag1 === 1)
      {
         if (pulseVal === "---"){
            pulseVal = "";
         }
         pulseVal += digit;
      }
      else if (flag1 === 2)
      {
         if (kaVal === "---")
         {
            kaVal = digit  + ".";
         }
         else
         {
            kaVal += digit;
         }
      }
   }

   signal clearClicked();
   width: 90
   height: 120
   onClearClicked: {
      if (flag1 === 1)
      {
         pulseVal = "---";
      }
      else if (flag1 === 2)
      {
         kaVal = "---";
      }
      else if (flag1 === 3)
      {
         pulseVal = oldMsText;
         kaVal= oldKaText;
         flag1 = 5;
      }
   }

   function check()
   {
      if (!checkPulse()) return "mS Out of Limits (25 to 500)";
      if (!checkKa()) return "KA Out of Limits";
      return "";
   }

   function checkPulse()
   {
      if (pulseVal === "---" )
      {
         msErr = true;
      }
      else
      {
         var x = parseInt(pulseVal, 10);
         msErr = x < 25 || x > 500;
      }
      return !msErr;
   }

   function checkKa()
   {
      if (kaVal === "---" )
      {
         kaErr = true;
      }
      else
      {
         var x = parseFloat(kaVal);
         kaErr = x < 0 || x > 5;
      }
      return !kaErr;
   }

   Text {text: line1; anchors.horizontalCenter: parent.horizontalCenter; color:w; font.pixelSize: 12}
   Rectangle {
       id: msRect
       height: 21
       color: bckgColor
       anchors.left: parent.left
       anchors.leftMargin: 0
       anchors.right: parent.right
       anchors.rightMargin: 0
       TextInput {id: pulse; x: 0; y: 0; color: fontColor; text: pulseVal; anchors.horizontalCenterOffset: -10; anchors.horizontalCenter: parent.horizontalCenter; anchors.verticalCenter: parent.verticalCenter; font.bold: true; font.italic: ita; font.pixelSize: 16
       inputMask: "XXX"}
       Text {id: msUnit; text: qsTr("mS"); font.bold: true; anchors.right: parent.right; anchors.rightMargin: 4; anchors.verticalCenter: parent.verticalCenter; color: fontColor; font.pixelSize: 16}
   }
   Text {text: line2; anchors.horizontalCenter: parent.horizontalCenter; color:w; font.pixelSize: 12}
   Text { y: 0;text: line3; anchors.horizontalCenter: parent.horizontalCenter; color:w; font.pixelSize: 12}

   Rectangle {
      id: kaRect
      height: 38
      color: bckgColor
      anchors.left: parent.left
      anchors.leftMargin: 0
      anchors.right: parent.right
      anchors.rightMargin: 0

       TextInput {id: ka; x: 0; y: 0; color: fontColor; text: kaVal; anchors.horizontalCenterOffset: -10; anchors.horizontalCenter: parent.horizontalCenter; font.bold: true; font.italic: ita; font.pixelSize: 16
       inputMask: "XXX"}
       Text { id: kaRange;x: 5; y: 17; color: fontColor; text: line4; anchors.bottom: parent.bottom; anchors.bottomMargin: 2; anchors.horizontalCenter: parent.horizontalCenter; font.pixelSize: 12}
       Text {id: kaUnit; x: 54; text: qsTr("KA"); anchors.top: parent.top; anchors.topMargin: 0; font.bold: true; color: fontColor;
          anchors.right: parent.right
          anchors.rightMargin: 4
          font.pixelSize: 16
       }
   }

   states: [
      State {
         name: "editMs"; when: flag1 === 1 && msErr === false
         PropertyChanges {target: msRect; color: w;}
         PropertyChanges {target: pulse; color: "black";}
         PropertyChanges {target: msUnit; color: "black";}
      },
      State {
         name: "editMsErr"; when: flag1 === 1 && msErr === true
         PropertyChanges {target: msRect; color: "red";}
         PropertyChanges {target: pulse; color: w;}
         PropertyChanges {target: msUnit; color: w;}
      },
      State {
         name: "editKa"; when: flag1 === 2 && kaErr === false
         PropertyChanges {target: kaRect; color: w;}
         PropertyChanges {target: ka; color: "black";}
         PropertyChanges {target: kaUnit; color: "black";}
         PropertyChanges {target: kaRange; color: "black";}
      },
      State {
         name: "editKaErr"; when: flag1 === 2 && kaErr === true
         PropertyChanges {target: kaRect; color: "red";}
         PropertyChanges {target: pulse; color: w;}
         PropertyChanges {target: kaUnit; color: w;}
         PropertyChanges {target: kaRange; color: w;}
      }
   ]

}
