// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1

Rectangle {
   id: rectangle1
   width: 400
   height: 250
   property color w: "white"
   color: "#315995"
   radius: 6
   property bool ita: false

   property bool errFlag;
   property string oldMsText;
   property string oldKaText;
   property int editing: 0;
   property bool savePrompt: false;

   property alias bckgColor: rectangle1.color; //for use in components
   property color fontColor: "white"

   signal runClicked();
   onRunClicked:
   {
      if (editing == 1)
      {
         errFlag = pk1.check() !== "";
         pk1.flag1 = 3;
      }
      if (editing == 2)
      {
         errFlag = pk2.check() !== "";
         pk2.flag1 = 3;
      }

      msgText.text = errFlag ? "Press <b>Clear</b> to discard changes"
                             : "Press <b>Save</b> to save changes, <b>Clear</b> to discard";
   }

   signal saveClicked();
   onSaveClicked:
   {
      if (editing == 1 && pk1.flag1 === 3 && pk1.check() === "")
      {
         pk1.flag1 = 5;
         return;
      }
      if (editing == 2 && pk2.flag1 === 3 && pk2.check() === "")
      {
         pk2.flag1 = 5;
         return;
      }

      msgText.text = "Cannot save out of limits values"
   }

   signal actionClicked(int id);
   onActionClicked:
   {
      if (id === 1)
      {
         pk1.flag1 = 1;
         oldMsText = pk1.pulseVal;
         oldKaText = pk1.kaVal;
      }
      else if (id === 2)
      {
         pk2.flag1 = 1;
         oldMsText = pk2.pulseVal;
         oldKaText = pk2.kaVal;
      }
      else if (id === 3)
      {
         sh1.flag1 = 1;
      }
      else if (id === 4)
      {
         sh2.flag1 = 1;
      }
   }

   signal enterClicked();
   onEnterClicked: {
      if (editing === 1)
      {
         msgText.text = pk1.check();
         errFlag = msgText.text != "";
         if (!errFlag)
         {
            pk1.enterClicked();
         }
      }
      if (editing === 2)
      {
         msgText.text = pk2.check();
         errFlag = msgText.text != "";
         if (!errFlag)
         {
            pk2.enterClicked();
         }
      }
      if (editing === 3)
      {
         sh1.flag1 = 0;
      }
      if (editing === 4)
      {
         sh2.flag1 = 0;
      }
   }

   signal clearClicked();
   onClearClicked: {
      if (editing == 1) pk1.clearClicked();
      if (editing == 2) pk2.clearClicked();
      if (editing == 3) sh1.clearClicked();
      if (editing == 4) sh2.clearClicked();
   }

   signal digitClicked(int digit);
   onDigitClicked: {
      if (editing === 1) pk1.digitClicked(digit);
      if (editing === 2) pk2.digitClicked(digit);
      if (editing === 3) sh1.digitClicked(digit);
      if (editing === 4) sh2.digitClicked(digit);
   }

   SqueezeHoldColumn
   {
      id: sh1;
      anchors.top: parent.top
      anchors.topMargin: 10
      anchors.left: parent.left
      anchors.leftMargin: 5
      spacing: 2
      line1: "SQUEEZE"
      val: "0150"
      onFlag1Changed: {
         editing = flag1 > 0 && flag1 < 5 ? 3 : 0;
      }
   }

   SqueezeHoldColumn
   {
      id: sh2;
      anchors.top: parent.top
      anchors.topMargin: 10
      anchors.right: parent.right
      anchors.rightMargin: 10
      spacing: 2
      line1: "HOLD"
      val: "0050"
      onFlag1Changed: {
         editing = flag1 > 0 && flag1 < 5 ? 4 : 0;
      }
   }

   PulseKaColumn{
      id: pk1
      x: 92
      y: 22
      anchors.top: parent.top
      anchors.topMargin: 22
      line1: "PULSE 1"
      pulseVal: "30";
      line2: "MEDIUM +"
      line3: "UPSLOPE: OFF"
      kaVal: "3.4"
      line4: "0.0 to 5.0"
      onFlag1Changed: {
         editing = flag1 > 0 && flag1 < 5 ? 1 : 0;
         savePrompt = pk1.flag1 === 3 || pk2.flag1 === 3;
      }
   }

   PulseKaColumn{
      id: pk2
      x: 219
      y: 22
      line1: "PULSE 2"
      pulseVal: "75";
      line2: "MEDIUM +"
      line3: " "
      kaVal: "4.8"
      line4: "0.0 to 5.0"
      onFlag1Changed: {
         editing = flag1 > 0 && flag1 < 5 ? 2 : 0;
         savePrompt = pk1.flag1 === 3 || pk2.flag1 === 3;
      }
   }

   Column
   {
      id: column1
      x: 96
      y: 170
      width: 208
      height: 49
      spacing: 2
      anchors.horizontalCenterOffset: 0
      anchors.horizontalCenter: parent.horizontalCenter
      Text {text: qsTr("WELD COUNTER: 000114"); anchors.horizontalCenter: parent.horizontalCenter; color:w; font.pixelSize: 12}
      Rectangle { y: 20;width: 200; height:14; color:"teal" ;anchors.horizontalCenter: parent.horizontalCenter}
      Text {text: qsTr("100%"); anchors.horizontalCenter: parent.horizontalCenter; color:w; font.pixelSize: 12}

   }
   Column
   {
      id: colSchedule
      x: 350
      y: 171
      width: 70
      height: 50
      anchors.right: parent.right
      anchors.rightMargin: 0
      Text {text: qsTr("SCHEDULE"); anchors.horizontalCenter: parent.horizontalCenter; color:w; font.pixelSize: 12}
      Rectangle{
         id: rectangle2
         height: 34
         color: "black"
         anchors.left: parent.left
         anchors.leftMargin: 0
         anchors.right: parent.right
         anchors.rightMargin: 0
         Text {text: qsTr("08"); verticalAlignment: Text.AlignVCenter; horizontalAlignment: Text.AlignHCenter; anchors.fill: parent; font.bold: true; color:w; font.pixelSize: 16}
      }
   }

   Rectangle {
       id: msgRect
       x: 0
       y: 142
       width: 400
       height: 21
       color: "#ff0000"
       anchors.bottom: parent.bottom
       anchors.bottomMargin: 0
       visible: false

       Text {
           id: msgText
           y: 4
           width: 390
           height: 17
           text: qsTr("text")
           anchors.left: parent.left
           anchors.leftMargin: 5
           anchors.verticalCenter: parent.verticalCenter
           font.pixelSize: 14
           color: w;
       }
   }


   states: [
      State {
         name: "edit"; when: editing > 0
         PropertyChanges {target: rectangle1; color: "black";}
//         PropertyChanges {target: pk1; bckgColor: "black";}
//         PropertyChanges {target: pk2; bckgColor: "black";}
         PropertyChanges {target: msgRect; visible: errFlag === true || savePrompt === true;}
      }
   ]
}
